elephant.parallel.ProcessPoolExecutor
=====================================

.. currentmodule:: elephant.parallel

.. autoclass:: ProcessPoolExecutor
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ProcessPoolExecutor.__init__
      ~ProcessPoolExecutor.execute
   
   

   
   
   